StateMachine

Struct StateMachine 

pub struct StateMachine { /* private fields */ }
State machine wrapping ClusterMetadata

Implementations

Source

impl StateMachine

pub fn new(snapshot_dir: impl Into<PathBuf>) -> Self

Create new state machine with a snapshot directory

pub fn new_default() -> Self

Create state machine for legacy callers (in-memory, temp dir for snapshots)

pub async fn metadata(&self) -> RwLockReadGuard<'_, ClusterMetadata>

Get current metadata (read-only)

pub async fn load_latest_snapshot(&self) -> Result<bool, StorageError<NodeId>>

Load the latest snapshot from disk (called during startup).

This avoids replaying the entire Raft log by restoring the most recent snapshot into the state machine.